@@ -1059,6 +1059,12 @@ class LocalClient(AbstractClient):
 
     # agent interactions
 
+    def construct_system_message(self, agent_id: str, message: str, user_id: str) -> str:
+        """
+        Construct a system message from a message.
+        """
+        return self.server.construct_system_message(agent_id=agent_id, message=message, actor=self.server.user_manager.get_user_by_id(user_id))
+
     def send_messages(
         self,
         agent_id: str,
