@@ -158,6 +158,10 @@ class OpenAIClient(LLMClientBase):
                 except ValueError as e:
                     logger.warning(f"Failed to convert tool function to structured output, tool={tool}, error={e}")
 
+        else:
+            # When there are no tools, delete tool_choice entirely from the request
+            delattr(data, 'tool_choice')
+
         return data.model_dump(exclude_unset=True)
 
     def fill_image_content_in_messages(self, openai_message_list):
@@ -255,6 +259,8 @@ class OpenAIClient(LLMClientBase):
         """
         client = OpenAI(**self._prepare_client_kwargs())
         response: ChatCompletion = client.chat.completions.create(**request_data)
+        if not response.object:
+            response.object = 'chat.completion'
         return response.model_dump()
 
     async def request_async(self, request_data: dict) -> dict:
